import { __extends, __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, ɵɵinject, NgModule } from '@angular/core';

var StorageService = /** @class */ (function () {
    function StorageService(storage) {
        this.storage = storage;
        this.prefix = 'Systelab';
    }
    StorageService.prototype.usePrefix = function (prefix) {
        this.prefix = prefix;
    };
    StorageService.prototype.clear = function () {
        this.storage.clear();
    };
    StorageService.prototype.put = function (key, value) {
        this.storage.setItem(this.prefix + '.' + key, JSON.stringify(value));
    };
    StorageService.prototype.get = function (key, defaultValue) {
        var value = this.parse(this.storage.getItem(this.prefix + '.' + key) || 'null') || null;
        return value ? value : defaultValue;
    };
    StorageService.prototype.remove = function (key) {
        this.storage.removeItem(this.prefix + '.' + key);
    };
    StorageService.prototype.removeStartsWith = function (startWith) {
        for (var i = this.storage.length - 1; i >= 0; i--) {
            if (this.storage.key(i).startsWith(this.prefix + '.' + startWith)) {
                this.storage.removeItem(this.storage.key(i));
            }
        }
    };
    StorageService.prototype.removeEndsWith = function (endsWith) {
        for (var i = this.storage.length - 1; i >= 0; i--) {
            if (this.storage.key(i).endsWith(endsWith)) {
                this.storage.removeItem(this.storage.key(i));
            }
        }
    };
    StorageService.prototype.parse = function (text) {
        try {
            return JSON.parse(text) || null;
        }
        catch (e) {
            return text;
        }
    };
    return StorageService;
}());

var LocalStorageService = /** @class */ (function (_super) {
    __extends(LocalStorageService, _super);
    function LocalStorageService() {
        return _super.call(this, localStorage) || this;
    }
    LocalStorageService.ɵprov = ɵɵdefineInjectable({ factory: function LocalStorageService_Factory() { return new LocalStorageService(); }, token: LocalStorageService, providedIn: "root" });
    LocalStorageService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], LocalStorageService);
    return LocalStorageService;
}(StorageService));

var compressor = pako;
var MemoryStorageService = /** @class */ (function () {
    function MemoryStorageService() {
        this.preferences = new Map();
    }
    MemoryStorageService.prototype.clear = function () {
        this.preferences.clear();
    };
    MemoryStorageService.prototype.put = function (key, value) {
        this.preferences.set(key, value);
    };
    MemoryStorageService.prototype.get = function (key, defaultValue) {
        var value = this.preferences.get(key);
        if (value === undefined || value === null) {
            if (defaultValue === undefined || defaultValue === null) {
                return value;
            }
            else {
                return defaultValue;
            }
        }
        else {
            return value;
        }
    };
    MemoryStorageService.prototype.remove = function (key) {
        this.preferences.delete(key);
    };
    MemoryStorageService.prototype.removeStartsWith = function (startWith) {
        var _this = this;
        this.preferences.forEach(function (value, key) {
            if (key.startsWith(startWith)) {
                _this.remove(key);
            }
        });
    };
    MemoryStorageService.prototype.removeEndsWith = function (endsWith) {
        var _this = this;
        this.preferences.forEach(function (value, key) {
            if (key.endsWith(endsWith)) {
                _this.remove(key);
            }
        });
    };
    MemoryStorageService.prototype.getInCompressFormat = function () {
        var passToServer = {};
        this.preferences.forEach(function (value, key) {
            passToServer[key] = value;
        });
        var binaryString = compressor.deflate(JSON.stringify(passToServer), { to: 'string' });
        return btoa(binaryString);
    };
    MemoryStorageService.prototype.getInStringFormat = function () {
        var passToServer = {};
        this.preferences.forEach(function (value, key) { return passToServer[key] = value; });
        return JSON.stringify(passToServer);
    };
    MemoryStorageService.prototype.putFromCompressFormat = function (compressed) {
        var _this = this;
        this.clear();
        // Do your best
        try {
            var result = compressor.inflate(atob(compressed), { to: 'string' });
            var parsed_1 = JSON.parse(result);
            Object.keys(parsed_1)
                .forEach(function (key) { return _this.preferences.set(key, parsed_1[key]); });
        }
        catch (ex) {
        }
    };
    MemoryStorageService.ɵprov = ɵɵdefineInjectable({ factory: function MemoryStorageService_Factory() { return new MemoryStorageService(); }, token: MemoryStorageService, providedIn: "root" });
    MemoryStorageService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], MemoryStorageService);
    return MemoryStorageService;
}());

var SessionStorageService = /** @class */ (function (_super) {
    __extends(SessionStorageService, _super);
    function SessionStorageService() {
        return _super.call(this, sessionStorage) || this;
    }
    SessionStorageService.ɵprov = ɵɵdefineInjectable({ factory: function SessionStorageService_Factory() { return new SessionStorageService(); }, token: SessionStorageService, providedIn: "root" });
    SessionStorageService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], SessionStorageService);
    return SessionStorageService;
}(StorageService));

var StorageType;
(function (StorageType) {
    StorageType[StorageType["IN_MEMORY_STORAGE"] = 1] = "IN_MEMORY_STORAGE";
    StorageType[StorageType["LOCAL_STORAGE"] = 2] = "LOCAL_STORAGE";
    StorageType[StorageType["SESSION_STORAGE"] = 3] = "SESSION_STORAGE";
})(StorageType || (StorageType = {}));
var PreferencesService = /** @class */ (function () {
    function PreferencesService(memoryService, localService, sessionService) {
        this.memoryService = memoryService;
        this.localService = localService;
        this.sessionService = sessionService;
        this.storage = StorageType.IN_MEMORY_STORAGE;
    }
    PreferencesService.prototype.setStorage = function (storage) {
        this.storage = storage;
    };
    PreferencesService.prototype.getStorage = function () {
        return this.storage;
    };
    PreferencesService.prototype.usePrefix = function (prefix) {
        if (this.storage === StorageType.LOCAL_STORAGE) {
            this.localService.usePrefix(prefix);
        }
        else if (this.storage === StorageType.SESSION_STORAGE) {
            this.sessionService.usePrefix(prefix);
        }
        else {
            console.error('You can not set a prefix for In-memory preferences');
        }
    };
    PreferencesService.prototype.clear = function () {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            this.memoryService.clear();
        }
        else if (this.storage === StorageType.LOCAL_STORAGE) {
            this.localService.clear();
        }
        else {
            this.sessionService.clear();
        }
    };
    PreferencesService.prototype.put = function (key, value) {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            this.memoryService.put(key, value);
        }
        else if (this.storage === StorageType.LOCAL_STORAGE) {
            this.localService.put(key, value);
        }
        else {
            this.sessionService.put(key, value);
        }
    };
    PreferencesService.prototype.get = function (key, defaultValue) {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            return this.memoryService.get(key, defaultValue);
        }
        else if (this.storage === StorageType.LOCAL_STORAGE) {
            return this.localService.get(key, defaultValue);
        }
        else {
            return this.sessionService.get(key, defaultValue);
        }
    };
    PreferencesService.prototype.remove = function (key) {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            this.memoryService.remove(key);
        }
        else if (this.storage === StorageType.LOCAL_STORAGE) {
            this.localService.remove(key);
        }
        else {
            this.sessionService.remove(key);
        }
    };
    PreferencesService.prototype.removeStartsWith = function (startWith) {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            this.memoryService.removeStartsWith(startWith);
        }
        else if (this.storage === StorageType.LOCAL_STORAGE) {
            this.localService.removeStartsWith(startWith);
        }
        else {
            this.sessionService.removeStartsWith(startWith);
        }
    };
    PreferencesService.prototype.removeEndsWith = function (endsWith) {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            this.memoryService.removeEndsWith(endsWith);
        }
        else if (this.storage === StorageType.LOCAL_STORAGE) {
            this.localService.removeEndsWith(endsWith);
        }
        else {
            this.sessionService.removeEndsWith(endsWith);
        }
    };
    PreferencesService.prototype.getInStringFormat = function () {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            return this.memoryService.getInStringFormat();
        }
        else {
            return '';
        }
    };
    PreferencesService.prototype.getInCompressFormat = function () {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            return this.memoryService.getInCompressFormat();
        }
        else {
            return '';
        }
    };
    PreferencesService.prototype.putFromCompressFormat = function (compressed) {
        if (this.storage === StorageType.IN_MEMORY_STORAGE) {
            this.memoryService.putFromCompressFormat(compressed);
        }
    };
    PreferencesService.ctorParameters = function () { return [
        { type: MemoryStorageService },
        { type: LocalStorageService },
        { type: SessionStorageService }
    ]; };
    PreferencesService.ɵprov = ɵɵdefineInjectable({ factory: function PreferencesService_Factory() { return new PreferencesService(ɵɵinject(MemoryStorageService), ɵɵinject(LocalStorageService), ɵɵinject(SessionStorageService)); }, token: PreferencesService, providedIn: "root" });
    PreferencesService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], PreferencesService);
    return PreferencesService;
}());

var SystelabPreferencesModule = /** @class */ (function () {
    function SystelabPreferencesModule() {
    }
    SystelabPreferencesModule = __decorate([
        NgModule({})
    ], SystelabPreferencesModule);
    return SystelabPreferencesModule;
}());

/*
 * Public API Surface of systelab-preferences
 */

/**
 * Generated bundle index. Do not edit.
 */

export { LocalStorageService, MemoryStorageService, PreferencesService, SessionStorageService, StorageType, SystelabPreferencesModule, StorageService as ɵa };
//# sourceMappingURL=systelab-preferences.js.map
